@@ -412,7 +412,7 @@ def test_get_latest_archive_with_lock_wait_calls_borg_with_lock_wait_flags():
     )
 
 
-def test_get_latest_archive_calls_borg_with_extra_borg_options():
+def test_get_latest_archive_calls_borg_with_list_extra_borg_options():
     expected_archive = {'name': 'archive-name', 'id': 'd34db33f'}
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
@@ -437,6 +437,42 @@ def test_get_latest_archive_calls_borg_with_extra_borg_options():
         borg_exit_codes=None,
     ).and_return(json.dumps({'archives': [expected_archive]}))
 
+    assert (
+        module.get_latest_archive(
+            'repo',
+            config={'extra_borg_options': {'list': '--extra "value with space"'}},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(),
+        )
+        == expected_archive
+    )
+
+
+def test_get_latest_archive_with_feature_available_calls_borg_with_repo_list_extra_borg_options():
+    expected_archive = {'name': 'archive-name', 'id': 'd34db33f'}
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args('last', 1).and_return(
+        ('--last', '1')
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        (
+            'borg',
+            'repo-list',
+            *BORG_LIST_LATEST_ARGUMENTS[:-1],
+            '--extra',
+            'value with space',
+            *BORG_LIST_LATEST_ARGUMENTS[-1:],
+        ),
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    ).and_return(json.dumps({'archives': [expected_archive]}))
+
     assert (
         module.get_latest_archive(
             'repo',
@@ -546,6 +582,7 @@ def test_get_latest_archive_calls_borg_with_working_directory():
 
 
 def test_make_repo_list_command_includes_log_info():
+    flexmock(module.feature).should_receive('available').and_return(False)
     insert_logging_mock(logging.INFO)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
@@ -563,6 +600,7 @@ def test_make_repo_list_command_includes_log_info():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -574,6 +612,7 @@ def test_make_repo_list_command_includes_log_info():
 
 
 def test_make_repo_list_command_includes_json_but_not_info():
+    flexmock(module.feature).should_receive('available').and_return(False)
     insert_logging_mock(logging.INFO)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
@@ -591,6 +630,7 @@ def test_make_repo_list_command_includes_json_but_not_info():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=True,
             prefix=None,
             match_archives=None,
@@ -602,6 +642,7 @@ def test_make_repo_list_command_includes_json_but_not_info():
 
 
 def test_make_repo_list_command_includes_log_debug():
+    flexmock(module.feature).should_receive('available').and_return(False)
     insert_logging_mock(logging.DEBUG)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
@@ -619,6 +660,7 @@ def test_make_repo_list_command_includes_log_debug():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -630,6 +672,7 @@ def test_make_repo_list_command_includes_log_debug():
 
 
 def test_make_repo_list_command_includes_json_but_not_debug():
+    flexmock(module.feature).should_receive('available').and_return(False)
     insert_logging_mock(logging.DEBUG)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
@@ -647,6 +690,7 @@ def test_make_repo_list_command_includes_json_but_not_debug():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=True,
             prefix=None,
             match_archives=None,
@@ -658,6 +702,7 @@ def test_make_repo_list_command_includes_json_but_not_debug():
 
 
 def test_make_repo_list_command_includes_json():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -674,6 +719,7 @@ def test_make_repo_list_command_includes_json():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=True,
             prefix=None,
             match_archives=None,
@@ -685,9 +731,10 @@ def test_make_repo_list_command_includes_json():
 
 
 def test_make_repo_list_command_includes_log_json():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(
         ('--log-json',),
-    ).and_return(())
+    ).and_return(()).and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
         None,
@@ -703,6 +750,7 @@ def test_make_repo_list_command_includes_log_json():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -714,9 +762,10 @@ def test_make_repo_list_command_includes_log_json():
 
 
 def test_make_repo_list_command_includes_lock_wait():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(
         ('--lock-wait', '5'),
-    ).and_return(())
+    ).and_return(()).and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
         None,
@@ -732,6 +781,7 @@ def test_make_repo_list_command_includes_lock_wait():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -742,7 +792,37 @@ def test_make_repo_list_command_includes_lock_wait():
     assert command == ('borg', 'list', '--lock-wait', '5', 'repo')
 
 
-def test_make_repo_list_command_includes_extra_borg_options():
+def test_make_repo_list_command_includes_list_extra_borg_options():
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None,
+        None,
+        '1.2.3',
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+
+    command = module.make_repo_list_command(
+        repository_path='repo',
+        config={'extra_borg_options': {'list': '--extra "value with space"'}},
+        local_borg_version='1.2.3',
+        repo_list_arguments=flexmock(
+            archive=None,
+            paths=None,
+            format=None,
+            json=False,
+            prefix=None,
+            match_archives=None,
+        ),
+        global_arguments=flexmock(),
+    )
+
+    assert command == ('borg', 'list', '--extra', 'value with space', 'repo')
+
+
+def test_make_repo_list_command_with_feature_available_includes_repo_list_extra_borg_options():
+    flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -759,6 +839,7 @@ def test_make_repo_list_command_includes_extra_borg_options():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -766,10 +847,11 @@ def test_make_repo_list_command_includes_extra_borg_options():
         global_arguments=flexmock(),
     )
 
-    assert command == ('borg', 'list', '--extra', 'value with space', 'repo')
+    assert command == ('borg', 'repo-list', '--extra', 'value with space', 'repo')
 
 
 def test_make_repo_list_command_includes_local_path():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -786,6 +868,7 @@ def test_make_repo_list_command_includes_local_path():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -798,6 +881,7 @@ def test_make_repo_list_command_includes_local_path():
 
 
 def test_make_repo_list_command_includes_remote_path():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').replace_with(
         lambda name, value: (f'--{name}', value) if value else (),
     )
@@ -816,6 +900,7 @@ def test_make_repo_list_command_includes_remote_path():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -828,6 +913,7 @@ def test_make_repo_list_command_includes_remote_path():
 
 
 def test_make_repo_list_command_includes_umask():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').replace_with(
         lambda name, value: (f'--{name}', value) if value else (),
     )
@@ -846,6 +932,7 @@ def test_make_repo_list_command_includes_umask():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -857,9 +944,10 @@ def test_make_repo_list_command_includes_umask():
 
 
 def test_make_repo_list_command_transforms_prefix_into_match_archives():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(()).and_return(
         ('--match-archives', 'sh:foo*'),
-    )
+    ).and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
         None,
@@ -872,7 +960,9 @@ def test_make_repo_list_command_transforms_prefix_into_match_archives():
         repository_path='repo',
         config={},
         local_borg_version='1.2.3',
-        repo_list_arguments=flexmock(archive=None, paths=None, json=False, prefix='foo'),
+        repo_list_arguments=flexmock(
+            archive=None, paths=None, format=None, json=False, prefix='foo'
+        ),
         global_arguments=flexmock(),
     )
 
@@ -880,9 +970,10 @@ def test_make_repo_list_command_transforms_prefix_into_match_archives():
 
 
 def test_make_repo_list_command_prefers_prefix_over_archive_name_format():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(()).and_return(
         ('--match-archives', 'sh:foo*'),
-    )
+    ).and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').never()
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
@@ -891,7 +982,9 @@ def test_make_repo_list_command_prefers_prefix_over_archive_name_format():
         repository_path='repo',
         config={'archive_name_format': 'bar-{now}'},
         local_borg_version='1.2.3',
-        repo_list_arguments=flexmock(archive=None, paths=None, json=False, prefix='foo'),
+        repo_list_arguments=flexmock(
+            archive=None, paths=None, format=None, json=False, prefix='foo'
+        ),
         global_arguments=flexmock(),
     )
 
@@ -899,6 +992,7 @@ def test_make_repo_list_command_prefers_prefix_over_archive_name_format():
 
 
 def test_make_repo_list_command_transforms_archive_name_format_into_match_archives():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -915,6 +1009,7 @@ def test_make_repo_list_command_transforms_archive_name_format_into_match_archiv
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -925,7 +1020,40 @@ def test_make_repo_list_command_transforms_archive_name_format_into_match_archiv
     assert command == ('borg', 'list', '--match-archives', 'sh:bar-*', 'repo')
 
 
+def test_make_repo_list_command_includes_format_from_command_line():
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(()).and_return(
+        ('--format', 'stuff')
+    )
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None,
+        None,
+        '1.2.3',
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+
+    command = module.make_repo_list_command(
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        repo_list_arguments=flexmock(
+            archive=None,
+            paths=None,
+            format='stuff',
+            json=False,
+            prefix=None,
+            match_archives=None,
+            short=False,
+        ),
+        global_arguments=flexmock(),
+    )
+
+    assert command == ('borg', 'list', '--format', 'stuff', 'repo')
+
+
 def test_make_repo_list_command_includes_short():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -942,6 +1070,7 @@ def test_make_repo_list_command_includes_short():
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
@@ -966,6 +1095,7 @@ def test_make_repo_list_command_includes_short():
     ),
 )
 def test_make_repo_list_command_includes_additional_flags(argument_name):
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -984,11 +1114,11 @@ def test_make_repo_list_command_includes_additional_flags(argument_name):
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
             find_paths=None,
-            format=None,
             **{argument_name: 'value'},
         ),
         global_arguments=flexmock(),
@@ -998,6 +1128,7 @@ def test_make_repo_list_command_includes_additional_flags(argument_name):
 
 
 def test_make_repo_list_command_with_match_archives_calls_borg_with_match_archives_flags():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -1019,11 +1150,11 @@ def test_make_repo_list_command_with_match_archives_calls_borg_with_match_archiv
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives='foo-*',
             find_paths=None,
-            format=None,
         ),
         global_arguments=flexmock(),
     )
@@ -1073,6 +1204,7 @@ def test_list_repository_with_json_calls_json_command_only():
 
 
 def test_make_repo_list_command_with_date_based_matching_calls_borg_with_date_based_flags():
+    flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None,
@@ -1091,6 +1223,7 @@ def test_make_repo_list_command_with_date_based_matching_calls_borg_with_date_ba
         repo_list_arguments=flexmock(
             archive=None,
             paths=None,
+            format=None,
             json=False,
             prefix=None,
             match_archives=None,
