@@ -5,36 +5,37 @@ from borgmatic.borg.pattern import Pattern, Pattern_source, Pattern_style, Patte
 from borgmatic.hooks.data_source import btrfs as module
 
 
-def test_path_is_a_subvolume_with_btrfs_success_call_returns_true():
+def test_path_is_a_subvolume_with_btrfs_inode_returns_true():
     module.path_is_a_subvolume.cache_clear()
-    flexmock(module.borgmatic.execute).should_receive(
-        'execute_command',
-    ).with_args(('btrfs', 'subvolume', 'show', '/mnt0'), output_log_level=None, close_fds=True)
-
-    assert module.path_is_a_subvolume('btrfs', '/mnt0') is True
-
-
-def test_path_is_a_subvolume_with_btrfs_error_returns_false():
-    module.path_is_a_subvolume.cache_clear()
-    flexmock(module.borgmatic.execute).should_receive(
-        'execute_command',
-    ).with_args(
-        ('btrfs', 'subvolume', 'show', '/mnt0'), output_log_level=None, close_fds=True
-    ).and_raise(
-        module.subprocess.CalledProcessError(1, 'btrfs'),
+    flexmock(module.os).should_receive('stat').and_return(
+        flexmock(st_ino=module.BTRFS_SUBVOLUME_INODE_NUMBER)
     )
 
-    assert module.path_is_a_subvolume('btrfs', '/mnt0') is False
+    assert module.path_is_a_subvolume('/mnt0') is True
+
+
+def test_path_is_a_subvolume_with_non_btrfs_inode_returns_false():
+    module.path_is_a_subvolume.cache_clear()
+    flexmock(module.os).should_receive('stat').and_return(flexmock(st_ino=12345))
+
+    assert module.path_is_a_subvolume('/mnt0') is False
 
 
 def test_path_is_a_subvolume_caches_result_after_first_call():
     module.path_is_a_subvolume.cache_clear()
-    flexmock(module.borgmatic.execute).should_receive(
-        'execute_command',
+    flexmock(module.os).should_receive('stat').and_return(
+        flexmock(st_ino=module.BTRFS_SUBVOLUME_INODE_NUMBER)
     ).once()
 
-    assert module.path_is_a_subvolume('btrfs', '/mnt0') is True
-    assert module.path_is_a_subvolume('btrfs', '/mnt0') is True
+    assert module.path_is_a_subvolume('/mnt0') is True
+    assert module.path_is_a_subvolume('/mnt0') is True
+
+
+def test_path_is_a_subvolume_with_missing_path_returns_false():
+    module.path_is_a_subvolume.cache_clear()
+    flexmock(module.os).should_receive('stat').and_raise(FileNotFoundError)
+
+    assert module.path_is_a_subvolume('/mnt0') is False
 
 
 def test_get_subvolume_property_with_invalid_btrfs_output_errors():
@@ -85,76 +86,66 @@ def test_get_subvolume_property_caches_result_after_first_call():
 
 
 def test_get_containing_subvolume_path_with_subvolume_self_returns_it():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(True)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/foo/bar').never()
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/foo').never()
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
+        True
+    )
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/').never()
     flexmock(module).should_receive('get_subvolume_property').and_return(False)
 
     assert module.get_containing_subvolume_path('btrfs', '/foo/bar/baz') == '/foo/bar/baz'
 
 
 def test_get_containing_subvolume_path_with_subvolume_parent_returns_it():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(False)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar'
-    ).and_return(True)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/foo').never()
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
+        False
+    )
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar').and_return(True)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/').never()
     flexmock(module).should_receive('get_subvolume_property').and_return(False)
 
     assert module.get_containing_subvolume_path('btrfs', '/foo/bar/baz') == '/foo/bar'
 
 
 def test_get_containing_subvolume_path_with_subvolume_grandparent_returns_it():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(False)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar'
-    ).and_return(False)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/foo').and_return(
-        True
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
+        False
     )
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/').never()
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar').and_return(False)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo').and_return(True)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/').never()
     flexmock(module).should_receive('get_subvolume_property').and_return(False)
 
     assert module.get_containing_subvolume_path('btrfs', '/foo/bar/baz') == '/foo'
 
 
 def test_get_containing_subvolume_path_without_subvolume_ancestor_returns_none():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(False)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar'
-    ).and_return(False)
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/foo').and_return(
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
         False
     )
-    flexmock(module).should_receive('path_is_a_subvolume').with_args('btrfs', '/').and_return(False)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar').and_return(False)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo').and_return(False)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/').and_return(False)
     flexmock(module).should_receive('get_subvolume_property').and_return(False)
 
     assert module.get_containing_subvolume_path('btrfs', '/foo/bar/baz') is None
 
 
 def test_get_containing_subvolume_path_with_read_only_subvolume_returns_none():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(True)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
+        True
+    )
     flexmock(module).should_receive('get_subvolume_property').and_return(True)
 
     assert module.get_containing_subvolume_path('btrfs', '/foo/bar/baz') is None
 
 
 def test_get_containing_subvolume_path_with_read_only_error_returns_none():
-    flexmock(module).should_receive('path_is_a_subvolume').with_args(
-        'btrfs', '/foo/bar/baz'
-    ).and_return(True)
+    flexmock(module).should_receive('path_is_a_subvolume').with_args('/foo/bar/baz').and_return(
+        True
+    )
     flexmock(module).should_receive('get_subvolume_property').and_raise(
         module.subprocess.CalledProcessError(1, 'wtf')
     )
@@ -340,16 +331,14 @@ def test_get_subvolumes_skips_non_config_patterns():
 @pytest.mark.parametrize(
     'subvolume_path,expected_snapshot_path',
     (
-        ('/foo/bar', '/foo/bar/.borgmatic-snapshot-1234/foo/bar'),
-        ('/', '/.borgmatic-snapshot-1234'),
+        ('/foo/bar', '/foo/bar/.borgmatic-snapshot/foo/bar'),
+        ('/', '/.borgmatic-snapshot'),
     ),
 )
 def test_make_snapshot_path_includes_stripped_subvolume_path(
     subvolume_path,
     expected_snapshot_path,
 ):
-    flexmock(module.os).should_receive('getpid').and_return(1234)
-
     assert module.make_snapshot_path(subvolume_path) == expected_snapshot_path
 
 
@@ -359,14 +348,14 @@ def test_make_snapshot_path_includes_stripped_subvolume_path(
         (
             '/foo/bar',
             Pattern('/foo/bar/baz'),
-            Pattern('/foo/bar/.borgmatic-snapshot-1234/./foo/bar/baz'),
+            Pattern('/foo/bar/.borgmatic-snapshot/./foo/bar/baz'),
         ),
-        ('/foo/bar', Pattern('/foo/bar'), Pattern('/foo/bar/.borgmatic-snapshot-1234/./foo/bar')),
+        ('/foo/bar', Pattern('/foo/bar'), Pattern('/foo/bar/.borgmatic-snapshot/./foo/bar')),
         (
             '/foo/bar',
             Pattern('^/foo/bar', Pattern_type.INCLUDE, Pattern_style.REGULAR_EXPRESSION),
             Pattern(
-                '^/foo/bar/.borgmatic-snapshot-1234/./foo/bar',
+                '^/foo/bar/.borgmatic-snapshot/./foo/bar',
                 Pattern_type.INCLUDE,
                 Pattern_style.REGULAR_EXPRESSION,
             ),
@@ -375,17 +364,17 @@ def test_make_snapshot_path_includes_stripped_subvolume_path(
             '/foo/bar',
             Pattern('/foo/bar', Pattern_type.INCLUDE, Pattern_style.REGULAR_EXPRESSION),
             Pattern(
-                '/foo/bar/.borgmatic-snapshot-1234/./foo/bar',
+                '/foo/bar/.borgmatic-snapshot/./foo/bar',
                 Pattern_type.INCLUDE,
                 Pattern_style.REGULAR_EXPRESSION,
             ),
         ),
-        ('/', Pattern('/foo'), Pattern('/.borgmatic-snapshot-1234/./foo')),
-        ('/', Pattern('/'), Pattern('/.borgmatic-snapshot-1234/./')),
+        ('/', Pattern('/foo'), Pattern('/.borgmatic-snapshot/./foo')),
+        ('/', Pattern('/'), Pattern('/.borgmatic-snapshot/./')),
         (
             '/foo/bar',
             Pattern('/foo/bar/./baz'),
-            Pattern('/foo/bar/.borgmatic-snapshot-1234/foo/bar/./baz'),
+            Pattern('/foo/bar/.borgmatic-snapshot/foo/bar/./baz'),
         ),
     ),
 )
@@ -394,8 +383,6 @@ def test_make_borg_snapshot_pattern_includes_slashdot_hack_and_stripped_pattern_
     pattern,
     expected_pattern,
 ):
-    flexmock(module.os).should_receive('getpid').and_return(1234)
-
     assert module.make_borg_snapshot_pattern(subvolume_path, pattern) == expected_pattern
 
 
@@ -409,26 +396,26 @@ def test_dump_data_sources_snapshots_each_subvolume_and_replaces_patterns():
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     )
     flexmock(module).should_receive('snapshot_subvolume').with_args(
         'btrfs',
         '/mnt/subvol1',
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).once()
     flexmock(module).should_receive('snapshot_subvolume').with_args(
         'btrfs',
         '/mnt/subvol2',
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).once()
     flexmock(module).should_receive('make_snapshot_exclude_pattern').with_args(
         '/mnt/subvol1',
     ).and_return(
         Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -437,7 +424,7 @@ def test_dump_data_sources_snapshots_each_subvolume_and_replaces_patterns():
         '/mnt/subvol2',
     ).and_return(
         Pattern(
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2/.borgmatic-snapshot-1234',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -445,16 +432,16 @@ def test_dump_data_sources_snapshots_each_subvolume_and_replaces_patterns():
     flexmock(module).should_receive('make_borg_snapshot_pattern').with_args(
         '/mnt/subvol1',
         object,
-    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1'))
+    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1'))
     flexmock(module).should_receive('make_borg_snapshot_pattern').with_args(
         '/mnt/subvol2',
         object,
-    ).and_return(Pattern('/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2'))
+    ).and_return(Pattern('/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2'))
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
         object,
         Pattern('/mnt/subvol1'),
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
             source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
         ),
     ).once()
@@ -462,14 +449,14 @@ def test_dump_data_sources_snapshots_each_subvolume_and_replaces_patterns():
         object,
         Pattern('/mnt/subvol2'),
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
             source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
         ),
     ).once()
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
         object,
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -477,7 +464,7 @@ def test_dump_data_sources_snapshots_each_subvolume_and_replaces_patterns():
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
         object,
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2/.borgmatic-snapshot-1234',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -507,18 +494,18 @@ def test_dump_data_sources_uses_custom_btrfs_command_in_commands():
         (module.Subvolume('/mnt/subvol1', contained_patterns=(Pattern('/mnt/subvol1'),)),),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     )
     flexmock(module).should_receive('snapshot_subvolume').with_args(
         '/usr/local/bin/btrfs',
         '/mnt/subvol1',
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).once()
     flexmock(module).should_receive('make_snapshot_exclude_pattern').with_args(
         '/mnt/subvol1',
     ).and_return(
         Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -526,19 +513,19 @@ def test_dump_data_sources_uses_custom_btrfs_command_in_commands():
     flexmock(module).should_receive('make_borg_snapshot_pattern').with_args(
         '/mnt/subvol1',
         object,
-    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1'))
+    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1'))
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
         object,
         Pattern('/mnt/subvol1'),
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
             source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
         ),
     ).once()
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
         object,
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -574,18 +561,18 @@ def test_dump_data_sources_with_findmnt_command_warns():
         (module.Subvolume('/mnt/subvol1', contained_patterns=(Pattern('/mnt/subvol1'),)),),
     ).once()
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     )
     flexmock(module).should_receive('snapshot_subvolume').with_args(
         'btrfs',
         '/mnt/subvol1',
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).once()
     flexmock(module).should_receive('make_snapshot_exclude_pattern').with_args(
         '/mnt/subvol1',
     ).and_return(
         Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -593,19 +580,19 @@ def test_dump_data_sources_with_findmnt_command_warns():
     flexmock(module).should_receive('make_borg_snapshot_pattern').with_args(
         '/mnt/subvol1',
         object,
-    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1'))
+    ).and_return(Pattern('/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1'))
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
         object,
         Pattern('/mnt/subvol1'),
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
             source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
         ),
     ).once()
     flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
         object,
         module.borgmatic.borg.pattern.Pattern(
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1/.borgmatic-snapshot-1234',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1/.borgmatic-snapshot',
             Pattern_type.NO_RECURSE,
             Pattern_style.FNMATCH,
         ),
@@ -637,7 +624,7 @@ def test_dump_data_sources_with_dry_run_skips_snapshot_and_patterns_update():
         (module.Subvolume('/mnt/subvol1', contained_patterns=(Pattern('/mnt/subvol1'),)),),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     )
     flexmock(module).should_receive('snapshot_subvolume').never()
     flexmock(module).should_receive('make_snapshot_exclude_pattern').never()
@@ -693,91 +680,59 @@ def test_remove_data_source_dumps_deletes_snapshots():
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/./mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/./mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/./mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/./mnt/subvol2',
     )
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol1/.borgmatic-*/mnt/subvol1')
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol2/.borgmatic-*/mnt/subvol2')
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol1/.borgmatic-*/mnt/subvol1',
     ).and_return(
-        (
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
-            '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
-        ),
+        ('/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',),
     )
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol2/.borgmatic-*/mnt/subvol2',
     ).and_return(
-        (
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-            '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
-        ),
+        ('/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',),
     )
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(True)
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-    ).and_return(True)
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
-    ).and_return(False)
     flexmock(module).should_receive('delete_snapshot').with_args(
         'btrfs',
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).once()
     flexmock(module).should_receive('delete_snapshot').with_args(
         'btrfs',
-        '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).once()
-    flexmock(module).should_receive('delete_snapshot').with_args(
-        'btrfs',
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-    ).once()
-    flexmock(module).should_receive('delete_snapshot').with_args(
-        'btrfs',
-        '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
-    ).never()
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234',
+        '/mnt/subvol1/.borgmatic-snapshot',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678',
-    ).and_return(True)
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234',
-    ).and_return(True)
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678',
+        '/mnt/subvol2/.borgmatic-snapshot',
     ).and_return(True)
     flexmock(module.shutil).should_receive('rmtree').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234',
+        '/mnt/subvol1/.borgmatic-snapshot',
     ).once()
     flexmock(module.shutil).should_receive('rmtree').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678',
+        '/mnt/subvol2/.borgmatic-snapshot',
     ).once()
-    flexmock(module.shutil).should_receive('rmtree').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234',
-    ).once()
-    flexmock(module.shutil).should_receive('rmtree').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678',
-    ).never()
 
     module.remove_data_source_dumps(
         hook_config=config['btrfs'],
@@ -855,50 +810,50 @@ def test_remove_data_source_dumps_with_dry_run_skips_deletes():
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/./mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/./mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/./mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/./mnt/subvol2',
     )
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol1/.borgmatic-*/mnt/subvol1')
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol2/.borgmatic-*/mnt/subvol2')
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol1/.borgmatic-*/mnt/subvol1',
     ).and_return(
         (
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
-            '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         ),
     )
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol2/.borgmatic-*/mnt/subvol2',
     ).and_return(
         (
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-            '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         ),
     )
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(False)
     flexmock(module).should_receive('delete_snapshot').never()
     flexmock(module.shutil).should_receive('rmtree').never()
@@ -940,21 +895,21 @@ def test_remove_data_source_without_snapshots_skips_deletes():
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/./mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/./mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/./mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/./mnt/subvol2',
     )
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol1/.borgmatic-*/mnt/subvol1')
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol2/.borgmatic-*/mnt/subvol2')
     flexmock(module.glob).should_receive('glob').and_return(())
@@ -980,50 +935,50 @@ def test_remove_data_source_dumps_with_delete_snapshot_file_not_found_error_bail
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/./mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/./mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/./mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/./mnt/subvol2',
     )
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol1/.borgmatic-*/mnt/subvol1')
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol2/.borgmatic-*/mnt/subvol2')
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol1/.borgmatic-*/mnt/subvol1',
     ).and_return(
         (
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
-            '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         ),
     )
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol2/.borgmatic-*/mnt/subvol2',
     ).and_return(
         (
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-            '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         ),
     )
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(False)
     flexmock(module).should_receive('delete_snapshot').and_raise(FileNotFoundError)
     flexmock(module.shutil).should_receive('rmtree').never()
@@ -1046,50 +1001,50 @@ def test_remove_data_source_dumps_with_delete_snapshot_called_process_error_bail
         ),
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol1').and_return(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/./mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/./mnt/subvol1',
     )
     flexmock(module).should_receive('make_snapshot_path').with_args('/mnt/subvol2').and_return(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/./mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/./mnt/subvol2',
     )
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol1/.borgmatic-*/mnt/subvol1')
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/mnt/subvol2/.borgmatic-*/mnt/subvol2')
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol1/.borgmatic-*/mnt/subvol1',
     ).and_return(
         (
-            '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
-            '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
+            '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
         ),
     )
     flexmock(module.glob).should_receive('glob').with_args(
         '/mnt/subvol2/.borgmatic-*/mnt/subvol2',
     ).and_return(
         (
-            '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
-            '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
+            '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
         ),
     )
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-1234/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol1/.borgmatic-snapshot-5678/mnt/subvol1',
+        '/mnt/subvol1/.borgmatic-snapshot/mnt/subvol1',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-1234/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(True)
     flexmock(module.os.path).should_receive('isdir').with_args(
-        '/mnt/subvol2/.borgmatic-snapshot-5678/mnt/subvol2',
+        '/mnt/subvol2/.borgmatic-snapshot/mnt/subvol2',
     ).and_return(False)
     flexmock(module).should_receive('delete_snapshot').and_raise(
         module.subprocess.CalledProcessError(1, 'command', 'error'),
@@ -1112,40 +1067,29 @@ def test_remove_data_source_dumps_with_root_subvolume_skips_duplicate_removal():
     )
 
     flexmock(module).should_receive('make_snapshot_path').with_args('/').and_return(
-        '/.borgmatic-snapshot-1234',
+        '/.borgmatic-snapshot',
     )
 
     flexmock(module.borgmatic.config.paths).should_receive(
         'replace_temporary_subdirectory_with_glob',
     ).with_args(
-        '/.borgmatic-snapshot-1234',
+        '/.borgmatic-snapshot',
         temporary_directory_prefix=module.BORGMATIC_SNAPSHOT_PREFIX,
     ).and_return('/.borgmatic-*')
 
     flexmock(module.glob).should_receive('glob').with_args('/.borgmatic-*').and_return(
-        ('/.borgmatic-snapshot-1234', '/.borgmatic-snapshot-5678'),
+        ('/.borgmatic-snapshot', '/.borgmatic-snapshot'),
     )
 
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/.borgmatic-snapshot-1234'
-    ).and_return(
-        True,
-    ).and_return(False)
-    flexmock(module.os.path).should_receive('isdir').with_args(
-        '/.borgmatic-snapshot-5678'
-    ).and_return(
-        True,
+    flexmock(module.os.path).should_receive('isdir').with_args('/.borgmatic-snapshot').and_return(
+        True
     ).and_return(False)
 
     flexmock(module).should_receive('delete_snapshot').with_args(
-        'btrfs', '/.borgmatic-snapshot-1234'
-    ).once()
-    flexmock(module).should_receive('delete_snapshot').with_args(
-        'btrfs', '/.borgmatic-snapshot-5678'
+        'btrfs', '/.borgmatic-snapshot'
     ).once()
 
     flexmock(module.os.path).should_receive('isdir').with_args('').and_return(False)
-
     flexmock(module.shutil).should_receive('rmtree').never()
 
     module.remove_data_source_dumps(
