@@ -203,6 +203,25 @@ def test_inject_pattern_with_root_pattern_prepends_it_along_with_corresponding_i
     ]
 
 
+def test_inject_pattern_with_root_pattern_and_override_excludes_false_omits_include_pattern():
+    patterns = [
+        module.borgmatic.borg.pattern.Pattern('/etc'),
+        module.borgmatic.borg.pattern.Pattern('/var'),
+    ]
+
+    module.inject_pattern(
+        patterns,
+        module.borgmatic.borg.pattern.Pattern('/foo/bar'),
+        override_excludes=False,
+    )
+
+    assert patterns == [
+        module.borgmatic.borg.pattern.Pattern('/foo/bar'),
+        module.borgmatic.borg.pattern.Pattern('/etc'),
+        module.borgmatic.borg.pattern.Pattern('/var'),
+    ]
+
+
 def test_replace_pattern_swaps_out_pattern_in_place():
     patterns = [
         module.borgmatic.borg.pattern.Pattern('/etc'),
@@ -236,7 +255,9 @@ def test_replace_pattern_with_unknown_pattern_falls_back_to_injecting():
         module.borgmatic.borg.pattern.Pattern('/lib'),
     ]
     flexmock(module).should_receive('inject_pattern').with_args(
-        patterns, module.borgmatic.borg.pattern.Pattern('/foo/bar')
+        patterns,
+        module.borgmatic.borg.pattern.Pattern('/foo/bar'),
+        override_excludes=False,
     ).once()
 
     module.replace_pattern(
@@ -244,27 +265,3 @@ def test_replace_pattern_with_unknown_pattern_falls_back_to_injecting():
         module.borgmatic.borg.pattern.Pattern('/unknown'),
         module.borgmatic.borg.pattern.Pattern('/foo/bar'),
     )
-
-
-def test_replace_pattern_with_root_pattern_swaps_it_in_along_with_corresponding_include_pattern():
-    patterns = [
-        module.borgmatic.borg.pattern.Pattern('/etc'),
-        module.borgmatic.borg.pattern.Pattern('/var'),
-        module.borgmatic.borg.pattern.Pattern('/lib'),
-    ]
-
-    module.replace_pattern(
-        patterns,
-        module.borgmatic.borg.pattern.Pattern('/var'),
-        module.borgmatic.borg.pattern.Pattern('/foo/bar'),
-    )
-
-    assert patterns == [
-        module.borgmatic.borg.pattern.Pattern('/etc'),
-        module.borgmatic.borg.pattern.Pattern('/foo/bar'),
-        module.borgmatic.borg.pattern.Pattern(
-            '/foo/bar',
-            type=module.borgmatic.borg.pattern.Pattern_type.INCLUDE,
-        ),
-        module.borgmatic.borg.pattern.Pattern('/lib'),
-    ]
