@@ -181,6 +181,7 @@ def test_database_names_to_dump_queries_mariadb_for_database_names():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -220,6 +221,7 @@ def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_ou
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -251,12 +253,53 @@ def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_ou
     assert names == ('baz',)
 
 
+def test_database_names_to_dump_runs_mariadb_with_socket_path():
+    environment = flexmock()
+    flexmock(module.borgmatic.hooks.credential.parse).should_receive(
+        'resolve_credential',
+    ).replace_with(lambda value, config: value)
+    flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
+    flexmock(module).should_receive('make_defaults_file_options').with_args(
+        'root',
+        'trustsome1',
+        None,
+    ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        (
+            'mariadb',
+            '--defaults-extra-file=/dev/fd/99',
+            '--socket',
+            '/socket',
+            '--skip-column-names',
+            '--batch',
+            '--execute',
+            'show schemas',
+        ),
+        environment=environment,
+        working_directory=None,
+    ).and_return('foo\nbar\nmysql\n').once()
+
+    names = module.database_names_to_dump(
+        {'name': 'all', 'socket_path': '/socket'},
+        {},
+        'root',
+        'trustsome1',
+        environment,
+        dry_run=False,
+    )
+
+    assert names == ('foo', 'bar')
+
+
 def test_database_names_to_dump_with_environment_password_transport_skips_defaults_file_and_passes_user_flag():
     environment = flexmock()
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').never()
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
@@ -291,6 +334,7 @@ def test_database_names_to_dump_runs_mariadb_with_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -329,6 +373,7 @@ def test_database_names_to_dump_runs_mariadb_without_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -706,6 +751,7 @@ def test_database_names_to_dump_runs_mariadb_with_list_options():
         ('--skip-ssl',),
         'mariadb.cnf',
     )
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -742,6 +788,7 @@ def test_database_names_to_dump_runs_non_default_mariadb_with_list_options():
         ('--skip-ssl',),
         'mariadb.cnf',
     )
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -776,6 +823,7 @@ def test_execute_dump_command_runs_mariadb_dump():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -789,6 +837,7 @@ def test_execute_dump_command_runs_mariadb_dump():
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
             '--add-drop-database',
+            '--single-transaction',
             '--databases',
             'foo',
             '--result-file',
@@ -823,6 +872,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').never()
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -831,6 +881,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
         (
             'mariadb-dump',
             '--add-drop-database',
+            '--single-transaction',
             '--user',
             'root',
             '--databases',
@@ -867,6 +918,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_add_drop_database():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -879,6 +931,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_add_drop_database():
         (
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
+            '--single-transaction',
             '--databases',
             'foo',
             '--result-file',
@@ -913,6 +966,9 @@ def test_execute_dump_command_runs_mariadb_dump_with_hostname_and_port():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(
+        'database.example.org'
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -926,6 +982,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_hostname_and_port():
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
             '--add-drop-database',
+            '--single-transaction',
             '--host',
             'database.example.org',
             '--port',
@@ -966,6 +1023,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -979,6 +1037,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_tls():
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
             '--add-drop-database',
+            '--single-transaction',
             '--ssl',
             '--databases',
             'foo',
@@ -1014,6 +1073,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1027,6 +1087,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_tls():
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
             '--add-drop-database',
+            '--single-transaction',
             '--skip-ssl',
             '--databases',
             'foo',
@@ -1062,6 +1123,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_username_and_password():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1075,6 +1137,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_username_and_password():
             'mariadb-dump',
             '--defaults-extra-file=/dev/fd/99',
             '--add-drop-database',
+            '--single-transaction',
             '--databases',
             'foo',
             '--result-file',
@@ -1109,6 +1172,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_options():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return(('--stuff=such',), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1123,6 +1187,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_options():
             '--defaults-extra-file=/dev/fd/99',
             '--stuff=such',
             '--add-drop-database',
+            '--single-transaction',
             '--databases',
             'foo',
             '--result-file',
@@ -1157,6 +1222,7 @@ def test_execute_dump_command_runs_non_default_mariadb_dump_with_options():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return(('--stuff=such',), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1171,6 +1237,7 @@ def test_execute_dump_command_runs_non_default_mariadb_dump_with_options():
             '--defaults-extra-file=/dev/fd/99',
             '--stuff=such',
             '--add-drop-database',
+            '--single-transaction',
             '--databases',
             'foo',
             '--result-file',
@@ -1205,6 +1272,7 @@ def test_execute_dump_command_with_duplicate_dump_skips_mariadb_dump():
     flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(True)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1236,6 +1304,7 @@ def test_execute_dump_command_with_dry_run_skips_mariadb_dump():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1269,6 +1338,7 @@ def test_restore_data_source_dump_runs_mariadb_to_restore():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1309,6 +1379,7 @@ def test_restore_data_source_dump_runs_mariadb_with_options():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return(('--harder',), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1351,6 +1422,7 @@ def test_restore_data_source_dump_runs_non_default_mariadb_with_options():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return(('--harder',), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1391,6 +1463,9 @@ def test_restore_data_source_dump_runs_mariadb_with_hostname_and_port():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1432,6 +1507,54 @@ def test_restore_data_source_dump_runs_mariadb_with_hostname_and_port():
     )
 
 
+def test_restore_data_source_dump_runs_mariadb_with_socket_path():
+    hook_config = [{'name': 'foo', 'socket_path': '/socket'}]
+    extract_process = flexmock(stdout=flexmock())
+
+    flexmock(module.borgmatic.hooks.credential.parse).should_receive(
+        'resolve_credential',
+    ).replace_with(lambda value, config: value)
+    flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
+    flexmock(module).should_receive('make_defaults_file_options').with_args(
+        None,
+        None,
+        None,
+    ).and_return(())
+    flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_with_processes').with_args(
+        (
+            'mariadb',
+            '--batch',
+            '--socket',
+            '/socket',
+        ),
+        processes=[extract_process],
+        output_log_level=logging.DEBUG,
+        input_file=extract_process.stdout,
+        environment={'USER': 'root'},
+        working_directory=None,
+    ).once()
+
+    module.restore_data_source_dump(
+        hook_config,
+        {},
+        data_source=hook_config[0],
+        dry_run=False,
+        extract_process=extract_process,
+        connection_params={
+            'hostname': None,
+            'port': None,
+            'username': None,
+            'password': None,
+        },
+        borgmatic_runtime_directory='/run/borgmatic',
+    )
+
+
 def test_restore_data_source_dump_runs_mariadb_with_tls():
     hook_config = [{'name': 'foo', 'tls': True}]
     extract_process = flexmock(stdout=flexmock())
@@ -1440,6 +1563,9 @@ def test_restore_data_source_dump_runs_mariadb_with_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1484,6 +1610,9 @@ def test_restore_data_source_dump_runs_mariadb_without_tls():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
@@ -1528,6 +1657,9 @@ def test_restore_data_source_dump_runs_mariadb_with_username_and_password():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'root',
         'trustsome1',
@@ -1575,6 +1707,9 @@ def test_restore_data_source_with_environment_password_transport_skips_defaults_
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').never()
     flexmock(module.os).should_receive('environ').and_return(
         {'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
@@ -1623,6 +1758,11 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: (
+            connection_params or {}
+        ).get(option)
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'cliusername',
         'clipassword',
@@ -1687,6 +1827,11 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').replace_with(
+        lambda option, data_source, connection_params=None, restore=False: data_source.get(
+            f'restore_{option}'
+        )
+    )
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         'restoreuser',
         'restorepass',
@@ -1737,6 +1882,7 @@ def test_restore_data_source_dump_with_dry_run_skips_restore():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module.database_config).should_receive('resolve_database_option').and_return(None)
     flexmock(module).should_receive('make_defaults_file_options').with_args(
         None,
         None,
