@@ -111,9 +111,13 @@ def test_dump_data_sources_with_path_injection_attack_gets_escaped():
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        '/path/to/working/dir'
+    )
     flexmock(module).should_receive('execute_command').with_args(
         (
             'sqlite3',
+            '-bail',
             "'/path/to/database1; naughty-command'",
             '.dump',
             '>',
@@ -121,6 +125,7 @@ def test_dump_data_sources_with_path_injection_attack_gets_escaped():
         ),
         shell=True,
         run_to_completion=False,
+        working_directory='/path/to/working/dir',
     ).and_return(processes[0])
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -166,10 +171,12 @@ def test_dump_data_sources_runs_non_default_sqlite_with_path_injection_attack_ge
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
         (
             'custom_sqlite',  # custom sqlite command
             "'*'",  # Should get shell escaped to prevent injection attacks.
+            '-bail',
             "'/path/to/database1; naughty-command'",
             '.dump',
             '>',
@@ -177,6 +184,7 @@ def test_dump_data_sources_runs_non_default_sqlite_with_path_injection_attack_ge
         ),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(processes[0])
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -322,14 +330,17 @@ def test_restore_data_source_dump_restores_database():
     hook_config = [{'path': '/path/to/database', 'name': 'database'}, {'name': 'other'}]
     extract_process = flexmock(stdout=flexmock())
 
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'sqlite3',
+            '-bail',
             '/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
@@ -356,15 +367,18 @@ def test_restore_data_source_dump_runs_non_default_sqlite_restores_database():
     ]
     extract_process = flexmock(stdout=flexmock())
 
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'custom_sqlite',
             "'*'",  # Should get shell escaped to prevent injection attacks.
+            '-bail',
             '/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
@@ -390,14 +404,17 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
     ]
     extract_process = flexmock(stdout=flexmock())
 
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'sqlite3',
+            '-bail',
             'cli/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
@@ -423,14 +440,17 @@ def test_restore_data_source_dump_runs_non_default_sqlite_with_connection_params
     ]
     extract_process = flexmock(stdout=flexmock())
 
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'custom_sqlite',
+            '-bail',
             'cli/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
@@ -462,11 +482,13 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'sqlite3',
+            '-bail',
             'config/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
@@ -493,14 +515,17 @@ def test_restore_data_source_dump_runs_non_default_sqlite_without_connection_par
     ]
     extract_process = flexmock(stdout=flexmock())
 
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'custom_sqlite',
+            '-bail',
             'config/path/to/database',
         ),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     flexmock(module.os).should_receive('remove').once()
